document.addEventListener('DOMContentLoaded', () => {
  let currentQuestion = 1;
  const totalQuestions = 10;
  let answers = {};
  
  const form = document.getElementById('assessment-form');
  const prevBtn = document.getElementById('prev-btn');
  const nextBtn = document.getElementById('next-btn');
  const progressBar = document.querySelector('.progress');
  const questionCounter = document.querySelector('.question-counter');
  
  function updateProgress() {
    progressBar.style.width = `${(currentQuestion/totalQuestions) * 100}%`;
    questionCounter.textContent = `Question ${currentQuestion} of ${totalQuestions}`;
  }
  
  function showQuestion(questionNumber) {
    document.querySelectorAll('.question').forEach(q => {
      q.classList.add('hidden');
    });
    document.querySelector(`[data-question="${questionNumber}"]`).classList.remove('hidden');
    
    prevBtn.disabled = questionNumber === 1;
    nextBtn.textContent = questionNumber === totalQuestions ? 'Submit' : 'Next';
    
    updateProgress();
  }
  
  // Handle slider value display
  document.querySelectorAll('.slider').forEach(slider => {
    const output = slider.nextElementSibling;
    slider.addEventListener('input', () => {
      output.textContent = `${slider.value} customers`;
      answers[slider.id] = parseInt(slider.value);
    });
  });
  
  // Handle frequency picker
  document.querySelectorAll('.frequency-picker button').forEach(btn => {
    btn.addEventListener('click', () => {
      btn.parentElement.querySelectorAll('button').forEach(b => b.classList.remove('selected'));
      btn.classList.add('selected');
      answers[btn.parentElement.parentElement.id] = parseInt(btn.dataset.value);
    });
  });
  
  // Navigation
  prevBtn.addEventListener('click', () => {
    if (currentQuestion > 1) {
      currentQuestion--;
      showQuestion(currentQuestion);
    }
  });
  
  nextBtn.addEventListener('click', () => {
    if (currentQuestion < totalQuestions) {
      currentQuestion++;
      showQuestion(currentQuestion);
    } else {
      calculateScore();
    }
  });
  
  function calculateScore() {
    // Calculate score based on answers (simplified)
    const score = Object.values(answers).reduce((sum, value) => sum + value, 0);
    const normalizedScore = Math.min(14, Math.max(1, Math.round(score/totalQuestions)));
    
    // Show results
    form.classList.add('hidden');
    const results = document.getElementById('results');
    results.classList.remove('hidden');
    document.getElementById('final-score').textContent = normalizedScore;
    
    // Add recommendations based on score
    const recommendations = results.querySelector('.recommendations');
    if (normalizedScore < 5) {
      recommendations.innerHTML = '<p>You might want to build your customer base before investing in email marketing.</p>';
    } else if (normalizedScore < 10) {
      recommendations.innerHTML = '<p>You\'re getting there! Consider starting with a basic email newsletter.</p>';
    } else {
      recommendations.innerHTML = '<p>You\'re ready for email marketing! Time to choose your email service provider.</p>';
    }
  }
  
  // Initialize
  showQuestion(1);
});
